// unemployment fluctuations in a discrete time search model

var w, theta, u, J, W, U, z, q, f;
varexo e;

parameters alpha, beta, delta, kappa, lambda, mbar, b, zbar, phiz, sigmaz, V;

alpha    = 0.5;    // match elasticity on unemployment
beta     = 1/1.02; // time discount factor
lambda   = 0.5;    // labor's weight in nash bargaining

zbar     = 0;      // long-run productivity *log* level

mbar     = 0.5;    // match efficiency
b        = 0.4;    // unemployment benefits 

delta    = 0.04;   // job destruction rate
kappa    = 0.28;   // vacancy cost

V        = 0;      // free entry condition

// AR(1) for shocks

phiz     = 0.95;
sigmaz   = 0.01;

model;

J = exp(z) - exp(w) + beta*(delta*V + (1-delta)*J(+1));

V = -kappa*exp(zbar) + beta*(exp(q)*J(+1)+(1-exp(q))*V);

W = exp(w) + beta*(delta*U(+1)+(1-delta)*W(+1));

U = b*exp(zbar) + beta*(exp(f)*W(+1)+(1-exp(f))*U(+1));

exp(u) - exp(u(-1)) = delta*(1-exp(u(-1))) - exp(f)*exp(u(-1));

W - U = lambda*(W-U+J-V);

exp(q) = mbar*exp(theta^(-alpha));

exp(f) = mbar*exp(theta^(1-alpha));

z = phiz*z(-1) + e;

end;

initval; 

w     = log(0.95);
theta = 1.82;
u     = log(0.056);
J     = 0.76;
W     = 46.2;
U     = 45.5;
z     = 0;
q     = log(0.37);
f     = log(0.67);

end;

steady;

shocks;
var e=sigmaz^2;
end;

stoch_simul(order=1,irf=100);



 

