function [residual, g1, g2, g3] = ps3_question3_dynamic(y, x, params, steady_state, it_)
%
% Status : Computes dynamic model for Dynare
%
% Inputs :
%   y         [#dynamic variables by 1] double    vector of endogenous variables in the order stored
%                                                 in M_.lead_lag_incidence; see the Manual
%   x         [nperiods by M_.exo_nbr] double     matrix of exogenous variables (in declaration order)
%                                                 for all simulation periods
%   steady_state  [M_.endo_nbr by 1] double       vector of steady state values
%   params    [M_.param_nbr by 1] double          vector of parameter values in declaration order
%   it_       scalar double                       time period for exogenous variables for which to evaluate the model
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the dynamic model equations in order of 
%                                          declaration of the equations.
%                                          Dynare may prepend auxiliary equations, see M_.aux_vars
%   g1        [M_.endo_nbr by #dynamic variables] double    Jacobian matrix of the dynamic model equations;
%                                                           rows: equations in order of declaration
%                                                           columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%   g2        [M_.endo_nbr by (#dynamic variables)^2] double   Hessian matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%   g3        [M_.endo_nbr by (#dynamic variables)^3] double   Third order derivative matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

%
% Model equations
%

residual = zeros(9, 1);
T81 = exp(y(4)^(-params(1)));
T86 = exp(y(4)^(1-params(1)));
lhs =y(6);
rhs =exp(y(9))-exp(y(3))+params(2)*(params(3)*params(11)+(1-params(3))*y(12));
residual(1)= lhs-rhs;
lhs =params(11);
rhs =(-params(4))*exp(params(8))+params(2)*(y(12)*exp(y(10))+params(11)*(1-exp(y(10))));
residual(2)= lhs-rhs;
lhs =y(7);
rhs =exp(y(3))+params(2)*(params(3)*y(14)+(1-params(3))*y(13));
residual(3)= lhs-rhs;
lhs =y(8);
rhs =exp(params(8))*params(7)+params(2)*(y(13)*exp(y(11))+y(14)*(1-exp(y(11))));
residual(4)= lhs-rhs;
lhs =exp(y(5))-exp(y(1));
rhs =params(3)*(1-exp(y(1)))-exp(y(11))*exp(y(1));
residual(5)= lhs-rhs;
lhs =y(7)-y(8);
rhs =params(5)*(y(6)+y(7)-y(8)-params(11));
residual(6)= lhs-rhs;
lhs =exp(y(10));
rhs =params(6)*T81;
residual(7)= lhs-rhs;
lhs =exp(y(11));
rhs =params(6)*T86;
residual(8)= lhs-rhs;
lhs =y(9);
rhs =params(9)*y(2)+x(it_, 1);
residual(9)= lhs-rhs;
if nargout >= 2,
  g1 = zeros(9, 15);

  %
  % Jacobian matrix
  %

  g1(1,3)=exp(y(3));
  g1(1,6)=1;
  g1(1,12)=(-(params(2)*(1-params(3))));
  g1(1,9)=(-exp(y(9)));
  g1(2,12)=(-(params(2)*exp(y(10))));
  g1(2,10)=(-(params(2)*(y(12)*exp(y(10))+params(11)*(-exp(y(10))))));
  g1(3,3)=(-exp(y(3)));
  g1(3,7)=1;
  g1(3,13)=(-(params(2)*(1-params(3))));
  g1(3,14)=(-(params(2)*params(3)));
  g1(4,13)=(-(params(2)*exp(y(11))));
  g1(4,8)=1;
  g1(4,14)=(-(params(2)*(1-exp(y(11)))));
  g1(4,11)=(-(params(2)*(y(13)*exp(y(11))+y(14)*(-exp(y(11))))));
  g1(5,1)=(-exp(y(1)))-(params(3)*(-exp(y(1)))-exp(y(11))*exp(y(1)));
  g1(5,5)=exp(y(5));
  g1(5,11)=exp(y(11))*exp(y(1));
  g1(6,6)=(-params(5));
  g1(6,7)=1-params(5);
  g1(6,8)=(-1)-(-params(5));
  g1(7,4)=(-(params(6)*T81*getPowerDeriv(y(4),(-params(1)),1)));
  g1(7,10)=exp(y(10));
  g1(8,4)=(-(params(6)*T86*getPowerDeriv(y(4),1-params(1),1)));
  g1(8,11)=exp(y(11));
  g1(9,2)=(-params(9));
  g1(9,9)=1;
  g1(9,15)=(-1);

if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],9,225);
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],9,3375);
end
end
end
end
