function [residual, g1, g2, g3] = ps3_question3_static(y, x, params)
%
% Status : Computes static model for Dynare
%
% Inputs : 
%   y         [M_.endo_nbr by 1] double    vector of endogenous variables in declaration order
%   x         [M_.exo_nbr by 1] double     vector of exogenous variables in declaration order
%   params    [M_.param_nbr by 1] double   vector of parameter values in declaration order
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the static model equations 
%                                          in order of declaration of the equations.
%                                          Dynare may prepend or append auxiliary equations, see M_.aux_vars
%   g1        [M_.endo_nbr by M_.endo_nbr] double    Jacobian matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%   g2        [M_.endo_nbr by (M_.endo_nbr)^2] double   Hessian matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%   g3        [M_.endo_nbr by (M_.endo_nbr)^3] double   Third derivatives matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

residual = zeros( 9, 1);

%
% Model equations
%

T75 = exp(y(2)^(-params(1)));
T80 = exp(y(2)^(1-params(1)));
lhs =y(4);
rhs =exp(y(7))-exp(y(1))+params(2)*(params(3)*params(11)+y(4)*(1-params(3)));
residual(1)= lhs-rhs;
lhs =params(11);
rhs =(-params(4))*exp(params(8))+params(2)*(y(4)*exp(y(8))+params(11)*(1-exp(y(8))));
residual(2)= lhs-rhs;
lhs =y(5);
rhs =exp(y(1))+params(2)*(params(3)*y(6)+(1-params(3))*y(5));
residual(3)= lhs-rhs;
lhs =y(6);
rhs =exp(params(8))*params(7)+params(2)*(y(5)*exp(y(9))+y(6)*(1-exp(y(9))));
residual(4)= lhs-rhs;
lhs =0;
rhs =params(3)*(1-exp(y(3)))-exp(y(9))*exp(y(3));
residual(5)= lhs-rhs;
lhs =y(5)-y(6);
rhs =params(5)*(y(4)+y(5)-y(6)-params(11));
residual(6)= lhs-rhs;
lhs =exp(y(8));
rhs =params(6)*T75;
residual(7)= lhs-rhs;
lhs =exp(y(9));
rhs =params(6)*T80;
residual(8)= lhs-rhs;
lhs =y(7);
rhs =y(7)*params(9)+x(1);
residual(9)= lhs-rhs;
if ~isreal(residual)
  residual = real(residual)+imag(residual).^2;
end
if nargout >= 2,
  g1 = zeros(9, 9);

  %
  % Jacobian matrix
  %

  g1(1,1)=exp(y(1));
  g1(1,4)=1-params(2)*(1-params(3));
  g1(1,7)=(-exp(y(7)));
  g1(2,4)=(-(params(2)*exp(y(8))));
  g1(2,8)=(-(params(2)*(y(4)*exp(y(8))+params(11)*(-exp(y(8))))));
  g1(3,1)=(-exp(y(1)));
  g1(3,5)=1-params(2)*(1-params(3));
  g1(3,6)=(-(params(2)*params(3)));
  g1(4,5)=(-(params(2)*exp(y(9))));
  g1(4,6)=1-params(2)*(1-exp(y(9)));
  g1(4,9)=(-(params(2)*(y(5)*exp(y(9))+y(6)*(-exp(y(9))))));
  g1(5,3)=(-(params(3)*(-exp(y(3)))-exp(y(9))*exp(y(3))));
  g1(5,9)=exp(y(9))*exp(y(3));
  g1(6,4)=(-params(5));
  g1(6,5)=1-params(5);
  g1(6,6)=(-1)-(-params(5));
  g1(7,2)=(-(params(6)*T75*getPowerDeriv(y(2),(-params(1)),1)));
  g1(7,8)=exp(y(8));
  g1(8,2)=(-(params(6)*T80*getPowerDeriv(y(2),1-params(1),1)));
  g1(8,9)=exp(y(9));
  g1(9,7)=1-params(9);
  if ~isreal(g1)
    g1 = real(g1)+2*imag(g1);
  end
if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],9,81);
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],9,729);
end
end
end
end
