
%%%%% run dynare on .mod file
%     suppress log file and warnings

dynare ps3_question3.mod nowarn nolog  

close all;

%var w, theta, u, J, W, U, z, q, f;

%%%%% recover coefficients of interest from dynare structures

%%%%% my ordering

n_w = 1; n_theta = 2; n_u = 3; n_z = 7;

%%%%% matrices for state-space representation
% s=As(-1) + Be, x=C*s(-1) + De

A = [oo_.dr.ghx(oo_.dr.inv_order_var(n_u),:);
     oo_.dr.ghx(oo_.dr.inv_order_var(n_z),:)];
 
B = [oo_.dr.ghu(oo_.dr.inv_order_var(n_u),:);
     oo_.dr.ghu(oo_.dr.inv_order_var(n_z),:)];
 

C = [oo_.dr.ghx(oo_.dr.inv_order_var(n_w),:);
     oo_.dr.ghx(oo_.dr.inv_order_var(n_theta),:)];

D = [oo_.dr.ghu(oo_.dr.inv_order_var(n_w),:);
     oo_.dr.ghu(oo_.dr.inv_order_var(n_theta),:)]; 
 

%%%%% in lecture notation

psi_uu = A(1,1);
psi_uz = B(1); % = A(1,2)/A(2,2)

psi_wu = C(1,1);
psi_tu = C(2,1); % theta

psi_wz = D(1);
psi_tz = D(2);   % theta




%%%%% Do a simple impulse response to a unit productivity shock

T = 100;           %% calculate for T periods after shock

time = (-1:1:T)';  %% steady state at t=-1, shock at t=0

shock    = zeros(size(time));
shock(2) = sigmaz;  %% set the impulse 

zt     = zeros(size(time));
wt     = zeros(size(time));
thetat = zeros(size(time));
ut     = zeros(size(time));
vt     = zeros(size(time));


for t=2:length(time)
    
zt(t)     = phiz*zt(t-1) + shock(t);         %% productivity
ut(t)     = psi_uu*ut(t-1) + psi_uz*zt(t);   %% unemployment rate
wt(t)     = psi_wu*ut(t-1) + psi_wz*zt(t);   %% wage rate
thetat(t) = psi_tu*ut(t-1) + psi_tz*zt(t);   %% tightness
vt(t)     = thetat(t)+ut(t);                 %% vacancy rate
    
end    


figure(1)
set(gcf,'DefaultLineLineWidth', 2);
plot(time,zt,'b--',time,ut,'r-',time,wt,'g:',time,thetat,'b-',time,vt,'m-',time,zeros(size(time)),'k--');
set(get(gcf,'CurrentAxes'),'FontSize',16,'LineWidth', 1.5)
xlabel('periods after shock','Interpreter','latex')
ylabel('log-deviation from steady state','Interpreter','latex')
set(gca,'DefaultTextInterpreter', 'latex','TickLabelInterpreter','latex')
l = legend('productivity','unemployment rate','wages','labor market tightness','vacancy rate','Location','Best');
set(l,'Interpreter','latex');
axis([-5, 100, -0.02 0.04])


%%%%% do a simple simulation

randn('state',10); %% set seed of random number generator

T = 500;           %% calculate for T periods after shock

time = (-1:1:T)';  %% steady state at t=-1, shock at t=0

shock    = randn(size(time))*sigmaz;

zt     = zeros(size(time));
wt     = zeros(size(time));
thetat = zeros(size(time));
ut     = zeros(size(time));
vt     = zeros(size(time));


for t=2:length(time)
    
zt(t)     = phiz*zt(t-1) + shock(t);         %% productivity
ut(t)     = psi_uu*ut(t-1) + psi_uz*zt(t);   %% unemployment rate
wt(t)     = psi_wu*ut(t-1) + psi_wz*zt(t);   %% wage rate
thetat(t) = psi_tu*ut(t-1) + psi_tz*zt(t);   %% tightness
vt(t)     = thetat(t)+ut(t);                 %% vacancy rate
    
end    


figure(2)
set(gcf,'DefaultLineLineWidth', 2);
plot(time,zt,'b--',time,ut,'r-',time,wt,'g:',time,thetat,'b-',time,vt,'m-',time,zeros(size(time)),'k--');
set(get(gcf,'CurrentAxes'),'FontSize',16,'LineWidth', 1.5)
xlabel('periods after shock','Interpreter','latex')
ylabel('log-deviation from steady state','Interpreter','latex')
set(gca,'DefaultTextInterpreter', 'latex','TickLabelInterpreter','latex')
l = legend('productivity','unemployment rate','wages','labor market tightness','vacancy rate','Location','Best');
set(l,'Interpreter','latex');
axis([-5, 500, -0.3 0.3])










